#
# spec file for package efreet
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           efreet
Version:        1.7.4
Release:        11.1
Summary:        FreeDesktop.org standards compatibility library
License:        BSD-2-Clause
Group:          System/GUI/Other
Url:            http://enlightenment.org/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  ecore-devel >= %version
BuildRequires:  eet-devel >= %version
BuildRequires:  eina-devel >= %version
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Standards handling for FreeDesktop.org standards. Part of Enlightenment Foundation Libraries.

%package -n libefreet1
Summary:        Efreet Dynamic Library
Group:          System/Libraries

%description -n libefreet1
Main dynamic library of Efreet package.

%package devel
Summary:        Efreet development files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       ecore-devel >= %version
Requires:       eet-devel >= %version
Requires:       eina-devel >= %version
Requires:       libefreet1 = %{version}

%description devel
Development files for Efreet package.

%package testsuite
Summary:        Efreet testsuite
Group:          Development/Libraries/C and C++
Requires:       libefreet1 = %{version}

%description testsuite
Testsuite of Efreet package.

%package doc-html
Summary:        HTML documentation of Eet
Group:          Documentation/HTML

%description doc-html
Documentation of Eet library in form of HTML pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
# fix permissions
find %{buildroot}%{_docdir} -type f | xargs chmod 0644
find %{buildroot}%{_docdir} -type d | xargs chmod 0755
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;
%find_lang %{name}

%post -n libefreet1 -p /sbin/ldconfig
%postun -n libefreet1 -p /sbin/ldconfig

%files -f %{name}.lang

%defattr(-,root,root)
%{_bindir}/efreet_*
%{_datadir}/efreet/
%exclude %{_datadir}/efreet/test
%{_libdir}/efreet/

%files -n libefreet1
%defattr(-, root, root)
%{_libdir}/libefreet*.so.*

%files devel
%defattr(-, root, root)
%{_libdir}/libefreet*.so
%{_includedir}/efreet-1/
%{_libdir}/pkgconfig/efreet*.pc

%files testsuite
%defattr(-, root, root)
%{_datadir}/efreet/test

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-11.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Efreet 1.7.3:
  * Add O_CLOEXEC to opened fds
  * Add XML output to doc
  * Add installation rule for doc
  * Fix build on Windows platforms.
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Sat Nov 24 2012 sleep_walker@suse.cz
- make find less efficient
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
  (No real chages - keeping version synced with other EFL libraries)
* Thu Nov 22 2012 sleep_walker@suse.cz
- improve summaries and descriptions
- fix license
- remove weird dependencies
- clean spec file a bit
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Fri Sep  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 20e1ef6df5bc33396bbf9f727bf8efcab4200c97
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 560e71e9e50579f86d60f34b2d2affb4c8ef7e8c
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a6313cae56c7ce9f233633ae1d69686516dcfc0d
* Wed Aug  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fdb4c9ffaa2c2aa94f4182fd3af84a3efabfa55c
* Thu Jul 19 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6ddeef0d6723d45b5c6c4a480a6467dce6335d31
* Mon Jul  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5a7534c41fd311fa42d02503fc91f08ee3cd0aa0
* Thu Jul  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 883aed31d9dc2dceffef398add00a967c2abe0c6
* Mon Jul  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 361ab3b412ee10ba1434f403a499871fa8ef5b5e
* Thu Jun 28 2012 sleep_walker@suse.cz
- add language files into package
* Thu Jun 28 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8620b3e358731d7e280dd493d0023e536108970a
* Wed Jun 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 220427dcd7c25d9d2f44f4baabc8e1ec1fdd6fd2
* Mon Jun 25 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 26e71ea6497c911c011b520cfe2460cfecc93dc5
* Mon Jun 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ebcd741639c10b597dfea2ea298a8d587b8d42f6
* Thu Jun 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b58e4654dcceca73b72f3d1229d2ccbe41d13cfa
* Mon Jun 11 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6ddbdb01853ce568b883def29ed9b5ec13ac966c
* Fri Jun  8 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a63b85f2388fe5d528bad840e25d565bc3a773d2
* Fri Jun  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 9c258bba97573d9022e84449b6973428f8dc675b
* Thu May 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision df0cb3252ce6b85ec576da22fc0babc526198f48
* Mon May 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 59e7a08c858a3e4a737bcb127b732fbfeda70b00
* Fri Apr 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b432496243f303feb9cca834d86ee75801b1538d
* Mon Apr 23 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 29f9b774267b6380aaa78409da6676084d4ea289
* Mon Apr 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ef6086bfdea96bdb098c3027616362ac599ba867
* Mon Apr  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 59f7e3e71d39447356bac9fc5247e6c368fa25ae
* Mon Mar 26 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 90a8391b8be88a617fcefe1e87b1cfb19ca9d1cb
* Wed Feb 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d7a83e19b97a62a092966ed36799094be52ae7c1
* Sun Jan 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fc0b140383bf0991044e231bf5247657d763c907
* Fri Jan 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 55f73c37f600fb62dcf41dbe61f71fac5adbb34a
* Wed Jan 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e347f44069568d6d04265f228c8be544a3e23781
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Fri Dec 16 2011 sleep_walker@suse.cz
- pre_configure --> pre_configure_hook
* Fri Dec 16 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 42c70e31bbcf48a07284f160877ea548eba815ba
* Fri Dec 16 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 42c70e31bbcf48a07284f160877ea548eba815ba
* Sat Dec 10 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 40ebd546fdf4c2971f59f645e4f374ae35589a67
* Tue Nov 15 2011 tcech@suse.com
- bump version to 1.0.999.65256
* Mon Nov 14 2011 tcech@suse.com
- bump version to 1.0.999.65190
* Tue Oct 18 2011 jreidinger@suse.com
- bump version to 1.0.999.64145
* Sat Oct 15 2011 tcech@suse.com
- add devel packages required to build as required for devel package
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 1.0.999.63807
* Mon Oct  3 2011 jreidinger@suse.com
- tweak spec file
* Mon Oct  3 2011 jreidinger@suse.com
- bump version to 1.0.999.63773
* Fri Sep 30 2011 jreidinger@suse.com
- bump version to 1.0.999.63723
* Fri Sep 30 2011 jreidinger@suse.com
- bump version
* Fri Sep 30 2011 jreidinger@suse.com
- bump version
* Wed Sep 28 2011 tcech@suse.com
- replace pkgconfig dependencies with package names
- add libjpeg as dependency
* Tue Sep 27 2011 jreidinger@suse.com
- update to 1.0.1
- spec cleanup
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package, version 1.0.0
